##  Define the Role of EA for the Subsequent Phases of the ERP Transformation
Beyond contributing to the discussions in this phase, establish clarity regarding who is involved in the ERP transformation, which roles and responsibilities the EA Practices versus other stakeholders, and the collaboration model.
For instance, it's common for an ERP Transformation or Program Manager to be responsible for the entire program. This person typically reports to the CIO (and other C-level positions). The Head of Enterprise Architecture reports to the Transformation Manager as part of the Program but also has a reporting line to the CIO in their wider EA role.
![Typical reporting structure in ERP transformation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754ae5f7a441014a025eda6ea5e7d8f_LowRes.png)
Typical reporting structure in ERP transformation
The roles, processes, and tasks of the stakeholders are typically determined by the overall ERP transformation program. The task of the leading EA is to establish a solid foundation for the effective usage of SAP LeanIX by setting up a governance process.
Aligning with key stakeholders on the following topics can facilitate achieving this goal:
  * What insights are needed for each stakeholder? What decisions do you/they intend to secure?
  * What data is required from which stakeholders at what point in time?
  * What process should they follow to provide that data? Often, a Program Management Office (PMO) is involved in gathering information from various sources - what is the interface between the PMO and the EA?
  * In what cadence should insights be shared? When is alignment needed?
  * How can you harness the EA community in your organization to support the transformation?


The outcome of this step should be the following assets:
  * Clearly defined picture of the stakeholder (EA and departments) ecosystem.
  * Data governance model with distributed responsibilities.
  * Reference materials showing how SAP LeanIX is positioned in the ecosystem alongside other tools (for example, Signavio, ServiceNow, JIRA, Confluence), where integrations can be beneficial for data leverage/synchronization.


![Data governance model example](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c80817a441014bd9fe244ccd334c5_LowRes.png)
Data governance model example
YesNo
Send
